==> ssp-center-api-0.5.84-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqAppDailyStatistics.java <==
/**
 * Project Name:media-manager-biz<br>
 * File Name:ReqAppDailyStatistics.java<br>
 * Package Name:cn.com.duiba.tuia.media.manager.model.req<br>
 * Date:2016年12月21日下午2:43:25<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.ssp.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.apache.commons.lang3.builder.ToStringBuilder;

import java.util.List;

/**
 * ClassName: ReqAppDailyStatistics <br/>
 * Function: 媒体每日数据请求对象. <br/>
 * date: 2016年12月21日 下午2:43:25 <br/>
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
@ApiModel
public class ReqAppDailyStatistics extends ReqDateQuery {

    /**序列号*/
    private static final long serialVersionUID = 2622662250199521271L;

    /** 媒体ID. */
    @ApiModelProperty(value = "媒ID", required = false)
    private Long   appId;

    /** 账号ID. */
    @ApiModelProperty(value = "账号ID", required = false)
    private Long   mediaId;

    /** The app name. */
    @ApiModelProperty(value = "媒体名称(用作导出)", required = false)
    private String appName;

    /** The platform. */
    @ApiModelProperty(value = "媒体所属平台(用作导出)", required = false)
    private String platform;

    @ApiModelProperty(value = "标签id", required = false)
    private Long     tagId;

    @ApiModelProperty(value = "标签模块类型：1媒体行业，2媒体流量，3广告位性质", required = false)
    private Integer     tagBlock;

    private List<Long> appIds;

    /**
     * 0-互动广告 1-展示广告
     */
    @ApiModelProperty(value = "接入广告类型", required = false)
    private Integer slotAccessType;

    /**
     * Gets the app id.
     *
     * @return the app id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * Sets the app id.
     *
     * @param appId the app id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * Gets the app name.
     *
     * @return the app name
     */
    public String getAppName() {
        return appName;
    }

    /**
     * Sets the app name.
     *
     * @param appName the app name
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * Gets the platform.
     *
     * @return the platform
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * Sets the platform.
     *
     * @param platform the platform
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }

    public Integer getTagBlock() {
        return tagBlock;
    }

    public void setTagBlock(Integer tagBlock) {
        this.tagBlock = tagBlock;
    }

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    public Integer getSlotAccessType() {
        return slotAccessType;
    }

    public void setSlotAccessType(Integer slotAccessType) {
        this.slotAccessType = slotAccessType;
    }

    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> ssp-center-api-0.8.76-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqAppDailyStatistics.java <==
/**
 * Project Name:media-manager-biz<br>
 * File Name:ReqAppDailyStatistics.java<br>
 * Package Name:cn.com.duiba.tuia.media.manager.model.req<br>
 * Date:2016年12月21日下午2:43:25<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.ssp.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.apache.commons.lang3.builder.ToStringBuilder;

import java.util.List;

/**
 * ClassName: ReqAppDailyStatistics <br/>
 * Function: 媒体每日数据请求对象. <br/>
 * date: 2016年12月21日 下午2:43:25 <br/>
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
@ApiModel
public class ReqAppDailyStatistics extends ReqDateQuery {

    /**序列号*/
    private static final long serialVersionUID = 2622662250199521271L;

    /** 媒体ID. */
    @ApiModelProperty(value = "媒ID", required = false)
    private Long   appId;

    /** 账号ID. */
    @ApiModelProperty(value = "账号ID", required = false)
    private Long   mediaId;

     /** 客户类型. */
    @ApiModelProperty(value = "账号ID", required = false)
    private Long   clientType;

    /** The app name. */
    @ApiModelProperty(value = "媒体名称(用作导出)", required = false)
    private String appName;

    /** The platform. */
    @ApiModelProperty(value = "媒体所属平台(用作导出)", required = false)
    private String platform;

    @ApiModelProperty(value = "标签id", required = false)
    private Long     tagId;

    @ApiModelProperty(value = "标签模块类型：1媒体行业，2媒体流量，3广告位性质", required = false)
    private Integer     tagBlock;

    private List<Long> appIds;

    @ApiModelProperty(value = "标签列表", required = false)
    private String tagIds;

    /**
     * 0-互动广告 1-展示广告
     */
    @ApiModelProperty(value = "接入广告类型", required = false)
    private Integer slotAccessType;

    public Long getClientType() {
        return clientType;
    }

    public void setClientType(Long clientType) {
        this.clientType = clientType;
    }

    /**
     * Gets the app id.
     *
     * @return the app id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * Sets the app id.
     *
     * @param appId the app id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * Gets the app name.
     *
     * @return the app name
     */
    public String getAppName() {
        return appName;
    }

    /**
     * Sets the app name.
     *
     * @param appName the app name
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * Gets the platform.
     *
     * @return the platform
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * Sets the platform.
     *
     * @param platform the platform
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }

    public Integer getTagBlock() {
        return tagBlock;
    }

    public void setTagBlock(Integer tagBlock) {
        this.tagBlock = tagBlock;
    }

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    public Integer getSlotAccessType() {
        return slotAccessType;
    }

    public void setSlotAccessType(Integer slotAccessType) {
        this.slotAccessType = slotAccessType;
    }

    public String getTagIds() {
        return tagIds;
    }

    public void setTagIds(String tagIds) {
        this.tagIds = tagIds;
    }

    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
